@@ -3,16 +3,16 @@ var searchData=
   ['map_0',['map',['../classlibcamera_1_1File.html#ae21f90c1db0adaab5769b4aa40aacd44',1,'libcamera::File']]],
   ['map_5fkeys_1',['map_keys',['../utils_8h.html#a9682828250eb4214779ddc2b9564415e',1,'libcamera::utils']]],
   ['mapbuffers_2',['mapBuffers',['../classlibcamera_1_1ipa_1_1ipu3_1_1IPAIPU3.html#a3b9f197dc13f318948d281cf748516c2',1,'libcamera::ipa::ipu3::IPAIPU3']]],
-  ['mappedbuffer_3',['MappedBuffer',['../classlibcamera_1_1MappedBuffer.html#a0585c7e99a32cc78d18fbd36bd11bffe',1,'libcamera::MappedBuffer::MappedBuffer()'],['../classlibcamera_1_1MappedBuffer.html#a91a5b45768e03f838314588b1e8cf51c',1,'libcamera::MappedBuffer::MappedBuffer(MappedBuffer &amp;&amp;other)']]],
+  ['mappedbuffer_3',['MappedBuffer',['../classlibcamera_1_1MappedBuffer.html#a91a5b45768e03f838314588b1e8cf51c',1,'libcamera::MappedBuffer::MappedBuffer(MappedBuffer &amp;&amp;other)'],['../classlibcamera_1_1MappedBuffer.html#a0585c7e99a32cc78d18fbd36bd11bffe',1,'libcamera::MappedBuffer::MappedBuffer()']]],
   ['mappedframebuffer_4',['MappedFrameBuffer',['../classlibcamera_1_1MappedFrameBuffer.html#a656d42eef1b5847073197a58cf860bf2',1,'libcamera::MappedFrameBuffer']]],
-  ['match_5',['match',['../classlibcamera_1_1PipelineHandler.html#a7cd5b652a2414b543ec20ba9dabf61b6',1,'libcamera::PipelineHandler::match()'],['../classlibcamera_1_1DeviceMatch.html#ae9923a86604c13eb08c0273b95d0a923',1,'libcamera::DeviceMatch::match()'],['../classlibcamera_1_1IPAModule.html#aeff066789ce1cfd94e14169cdcd6c7c7',1,'libcamera::IPAModule::match()']]],
+  ['match_5',['match',['../classlibcamera_1_1DeviceMatch.html#ae9923a86604c13eb08c0273b95d0a923',1,'libcamera::DeviceMatch::match()'],['../classlibcamera_1_1IPAModule.html#aeff066789ce1cfd94e14169cdcd6c7c7',1,'libcamera::IPAModule::match()'],['../classlibcamera_1_1PipelineHandler.html#a7cd5b652a2414b543ec20ba9dabf61b6',1,'libcamera::PipelineHandler::match()']]],
   ['max_6',['max',['../classlibcamera_1_1ControlInfo.html#ace0e212b17680d64466520d251f1cb4e',1,'libcamera::ControlInfo']]],
   ['mbuscodes_7',['mbusCodes',['../classlibcamera_1_1CameraSensor.html#acd6b5eb335c945fa2ff01ad3cbc7ad3b',1,'libcamera::CameraSensor']]],
   ['mediadevice_8',['MediaDevice',['../classlibcamera_1_1MediaDevice.html#ab950a4880c2bea6d94bfd6ecfe46e5f5',1,'libcamera::MediaDevice']]],
   ['mediaobject_9',['MediaObject',['../classlibcamera_1_1MediaObject.html#a040304e6607c1742fa50a1cfbe1064a5',1,'libcamera::MediaObject']]],
   ['merge_10',['merge',['../classlibcamera_1_1ControlList.html#afb929046d68faa5dea1b43ce4028721f',1,'libcamera::ControlList']]],
-  ['message_11',['message',['../classlibcamera_1_1EventNotifier.html#a83550c524a9bcc0ea582e876ca43c04d',1,'libcamera::EventNotifier::message()'],['../classlibcamera_1_1Object.html#a5328cab1412743716aa2748eeded8e80',1,'libcamera::Object::message()'],['../classlibcamera_1_1Timer.html#a3ed22e72f2b3001a17e8aedcc6374c0c',1,'libcamera::Timer::message()']]],
-  ['message_12',['Message',['../classlibcamera_1_1Message.html#a820b1e559680365eef4d156915331e81',1,'libcamera::Message']]],
+  ['message_11',['Message',['../classlibcamera_1_1Message.html#a820b1e559680365eef4d156915331e81',1,'libcamera::Message']]],
+  ['message_12',['message',['../classlibcamera_1_1EventNotifier.html#a83550c524a9bcc0ea582e876ca43c04d',1,'libcamera::EventNotifier::message()'],['../classlibcamera_1_1Object.html#a5328cab1412743716aa2748eeded8e80',1,'libcamera::Object::message()'],['../classlibcamera_1_1Timer.html#a3ed22e72f2b3001a17e8aedcc6374c0c',1,'libcamera::Timer::message()']]],
   ['metadata_13',['metadata',['../classlibcamera_1_1FrameBuffer.html#a95daecbcca64c22e241bbbe29ebdf67e',1,'libcamera::FrameBuffer::metadata()'],['../classlibcamera_1_1FrameBuffer_1_1Private.html#acc3a4ea50af29b5246a92aae79023783',1,'libcamera::FrameBuffer::Private::metadata()'],['../classlibcamera_1_1Request.html#ac620539cc50a28bd9ff9f8f697eb86c3',1,'libcamera::Request::metadata()']]],
   ['min_14',['min',['../classlibcamera_1_1ControlInfo.html#afb9582361884572819f28ed3e692cb50',1,'libcamera::ControlInfo']]],
   ['model_15',['model',['../classlibcamera_1_1CameraLens.html#ac78118e36bfaacd6cca8bcdbe5c18a59',1,'libcamera::CameraLens::model()'],['../classlibcamera_1_1CameraSensor.html#a69ca8058047b7309a6db29ea5d3daf1b',1,'libcamera::CameraSensor::model()'],['../classlibcamera_1_1MediaDevice.html#a73f32f10c2087b482e44e0acd93b29e8',1,'libcamera::MediaDevice::model()'],['../classlibcamera_1_1V4L2Subdevice.html#ac8e06bbad91b294a1ac6fe4568986b9b',1,'libcamera::V4L2Subdevice::model()']]],
